# M(N)ultitool - a multitool for Numerical Methods

## Compatibility & requirements

This module assumes you are using python `3.x` & have the following packages installed:

- `matplotlib`
- `numpy`
- `scipy`

## Installation

To install, run `pip install mnultitool`

## Docs

Docs are available [here](https://artus9033.github.io/MNultitool/index.html) and are automatically compiled after each commit.
